@@ -10,7 +10,7 @@
 #ifndef FILESEARCHTAB_H
 #define FILESEARCHTAB_H
 
-#include "lokalizesubwindowbase.h"
+#include "lokalizetabpagebase.h"
 #include "pos.h"
 #include "qaview.h"
 #include "rule.h"
@@ -41,7 +41,7 @@ class Ui_FileSearchOptions;
 /**
  * Global file search/repalce tab
  */
-class FileSearchTab : public LokalizeSubwindowBase2
+class FileSearchTab : public LokalizeTabPageBase
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.Lokalize.FileSearch")
@@ -121,14 +121,9 @@ struct FileSearchResult {
 
     bool isApproved{};
     TargetState state;
-    // Phase activePhase;
 
     QVector<StartLen> sourcePositions;
     QVector<StartLen> targetPositions;
-
-    // int matchedQaRule;
-    // short notePos;
-    // char  noteindex;
 };
 
 typedef QMap<QString, QVector<FileSearchResult>> FileSearchResults;
