@@ -7,11 +7,10 @@
   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#include "lokalize_debug.h"
-
 #include "catalogstring.h"
 #include "editortab.h"
 #include "jobs.h"
+#include "lokalize_debug.h"
 #include "lokalizemainwindow.h"
 #include "pos.h"
 #include "prefs.h"
@@ -29,10 +28,18 @@
 #include <QMetaType>
 #include <QString>
 
+#include <kiconthemes_version.h>
+
+#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
+#if HAVE_STYLE_MANAGER
+#include <KStyleManager>
+#endif
+
+#include <KAboutData>
 #include <KCrash>
 #include <KDBusService>
-#include <kaboutdata.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
+#include <KIconTheme>
 
 int main(int argc, char **argv)
 {
@@ -44,10 +51,21 @@ int main(int argc, char **argv)
     qputenv("QT_QPA_PLATFORM", "xcb");
 #endif
 
+#if KICONTHEMES_VERSION >= QT_VERSION_CHECK(6, 3, 0)
+    KIconTheme::initTheme();
+#endif
+
     TM::threadPool()->setMaxThreadCount(1);
     TM::threadPool()->setExpiryTimeout(-1);
     QThreadPool::globalInstance()->setMaxThreadCount(1);
+
     QApplication app(argc, argv);
+
+#if HAVE_STYLE_MANAGER
+    KStyleManager::initStyle();
+#endif
+
+
     KLocalizedString::setApplicationDomain("lokalize");
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("lokalize")));
     QCommandLineParser parser;
@@ -79,14 +97,12 @@ int main(int argc, char **argv)
     KAboutData::setApplicationData(about);
     KCrash::initialize();
     about.setupCommandLine(&parser);
-    // parser.addOption(QCommandLineOption(QStringList() <<  QLatin1String("source"), i18n( "Source for the merge mode" ), QLatin1String("URL")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("noprojectscan"), i18n("Do not scan files of the project.")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("project"), i18n("Load specified project."), QStringLiteral("filename")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[URL]"), i18n("Document to open")));
     parser.process(app);
     about.processCommandLine(&parser);
 
-    // qCDebug(LOKALIZE_LOG) is important as it avoids compile 'optimization'.
     qCDebug(LOKALIZE_LOG) << qRegisterMetaType<DocPosition>();
     qCDebug(LOKALIZE_LOG) << qRegisterMetaType<DocPos>();
     qCDebug(LOKALIZE_LOG) << qRegisterMetaType<InlineTag>();
@@ -127,9 +143,6 @@ int main(int argc, char **argv)
 
         if (urls.size())
             new DelayedFileOpener(urls, lmw);
-
-        // Project::instance()->model()->setCompleteScan(parser.isSet("noprojectscan"));// TODO: negate check (and ensure nobody passes the no-op
-        // --noprojectscan argument)
     }
     int code = app.exec();
 
@@ -152,7 +165,6 @@ int main(int argc, char **argv)
         Project::instance()->model()->threadPool()->waitForDone(1000);
         TM::threadPool()->waitForDone(1000);
         QThreadPool::globalInstance()->waitForDone(1000);
-        // qCDebug(LOKALIZE_LOG)<<"QCoreApplication::processEvents()...";
         QCoreApplication::processEvents();
         QCoreApplication::sendPostedEvents(nullptr, 0);
     }
